@@ -718,7 +718,8 @@ void Client::updateShape()
     } else if (app_noborder) {
         xcb_shape_mask(connection(), XCB_SHAPE_SO_SET, XCB_SHAPE_SK_BOUNDING, frameId(), 0, 0, XCB_PIXMAP_NONE);
         detectNoBorder();
-        app_noborder = noborder = rules()->checkNoBorder(noborder);
+        app_noborder = noborder;
+        noborder = rules()->checkNoBorder(noborder || motif_noborder);
         updateDecoration(true);
     }
 
@@ -1457,6 +1458,7 @@ void Client::setDesktop(int desktop)
         return;
 
     int was_desk = desk;
+    const bool wasOnCurrentDesktop = isOnCurrentDesktop();
     desk = desktop;
     info->setDesktop(desktop);
     if ((was_desk == NET::OnAllDesktops) != (desktop == NET::OnAllDesktops)) {
@@ -1486,6 +1488,8 @@ void Client::setDesktop(int desktop)
     if (tabGroup())
         tabGroup()->updateStates(this, TabGroup::Desktop);
     emit desktopChanged();
+    if (wasOnCurrentDesktop != isOnCurrentDesktop())
+        emit desktopPresenceChanged(this, was_desk);
 }
 
 /**
